@@ -9,7 +9,7 @@ llm = typer.Typer(short_help="The LLM management.")
 
 @llm.command(short_help="Start a server for the LLM.")
 def serve(
-    model: str = typer.Argument("", help="The ID of the LLM model to use."),
+    model: str = typer.Argument("", help="The ID or the path of the LLM model to use."),
     model_name: str = typer.Argument("", help="The name of the LLM model to use."),
     parallal_size: int = typer.Option(1, help="The number of GPUs to use."),
     host: str = typer.Option("0.0.0.0", help="The host of the server."),
@@ -21,6 +21,7 @@ def serve(
     ),
     max_num_seq: int = typer.Option(2, help="The maximum number of sequences."),
     max_model_len: int = typer.Option(4096, help="The maximum model length."),
+    local: bool = typer.Option(False, help="Whether to load the model locally."),
 ):
     from mw_python_sdk.llm.inference import serve
 
@@ -35,6 +36,7 @@ def serve(
         quantization=quantization,
         load_format=load_format,
         enforce_eager=enforce_eager,
+        local=local
     )
 
 
@@ -54,16 +56,19 @@ def download_file_if_not_exists(url, save_path):
 @llm.command(short_help="Collect the metrics of a running LLM server.")
 def collect(
     duration: int = typer.Option(600, help="The duration of the collection."),
+    print_metrics: bool = typer.Option(False, help="Whether to print the metrics."),
 ):
     from mw_python_sdk.llm.monitor import collect_with_duration
     from mw_python_sdk import create_dataset
+
     if not os.path.exists("./llm_benchmark"):
         os.makedirs("./llm_benchmark")
     if os.path.exists("./llm_benchmark/metrics.csv"):
         os.remove("./llm_benchmark/metrics.csv")
-    collect_with_duration(duration, "./llm_benchmark/metrics.csv")
+    collect_with_duration(duration, "./llm_benchmark/metrics.csv", print_metrics)
     create_dataset("llm_benchmark", "./llm_benchmark", "", "llm benchmark metrics")
 
+
 @llm.command(short_help="Bench an online serving model.")
 def bench(
     base_url: str = typer.Option(
